==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/MemoryStressorBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MemoryStressorBuilder extends MemoryStressorFluentImpl<MemoryStressorBuilder> implements VisitableBuilder<MemoryStressor,MemoryStressorBuilder>{
  public MemoryStressorBuilder() {
    this(false);
  }
  public MemoryStressorBuilder(Boolean validationEnabled) {
    this(new MemoryStressor(), validationEnabled);
  }
  public MemoryStressorBuilder(MemoryStressorFluent<?> fluent) {
    this(fluent, false);
  }
  public MemoryStressorBuilder(MemoryStressorFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MemoryStressor(), validationEnabled);
  }
  public MemoryStressorBuilder(MemoryStressorFluent<?> fluent,MemoryStressor instance) {
    this(fluent, instance, false);
  }
  public MemoryStressorBuilder(MemoryStressorFluent<?> fluent,MemoryStressor instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withOptions(instance.getOptions());
      fluent.withSize(instance.getSize());
      fluent.withWorkers(instance.getWorkers());
    }
    this.validationEnabled = validationEnabled; 
  }
  public MemoryStressorBuilder(MemoryStressor instance) {
    this(instance,false);
  }
  public MemoryStressorBuilder(MemoryStressor instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withOptions(instance.getOptions());
      this.withSize(instance.getSize());
      this.withWorkers(instance.getWorkers());
    }
    this.validationEnabled = validationEnabled; 
  }
  MemoryStressorFluent<?> fluent;
  Boolean validationEnabled;
  public MemoryStressor build() {
    MemoryStressor buildable = new MemoryStressor(fluent.getOptions(),fluent.getSize(),fluent.getWorkers());
    return buildable;
  }
  
}

==> chaosmesh-model-6.8.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/MemoryStressorBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MemoryStressorBuilder extends MemoryStressorFluent<MemoryStressorBuilder> implements VisitableBuilder<MemoryStressor,MemoryStressorBuilder>{
  public MemoryStressorBuilder() {
    this(false);
  }
  public MemoryStressorBuilder(Boolean validationEnabled) {
    this(new MemoryStressor(), validationEnabled);
  }
  public MemoryStressorBuilder(MemoryStressorFluent<?> fluent) {
    this(fluent, false);
  }
  public MemoryStressorBuilder(MemoryStressorFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MemoryStressor(), validationEnabled);
  }
  public MemoryStressorBuilder(MemoryStressorFluent<?> fluent,MemoryStressor instance) {
    this(fluent, instance, false);
  }
  public MemoryStressorBuilder(MemoryStressorFluent<?> fluent,MemoryStressor instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new MemoryStressor());

    if (instance != null) {
      fluent.withOptions(instance.getOptions());
      fluent.withSize(instance.getSize());
      fluent.withWorkers(instance.getWorkers());
      fluent.withOptions(instance.getOptions());
      fluent.withSize(instance.getSize());
      fluent.withWorkers(instance.getWorkers());
    }
    this.validationEnabled = validationEnabled; 
  }
  public MemoryStressorBuilder(MemoryStressor instance) {
    this(instance,false);
  }
  public MemoryStressorBuilder(MemoryStressor instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new MemoryStressor());

    if (instance != null) {
      this.withOptions(instance.getOptions());
      this.withSize(instance.getSize());
      this.withWorkers(instance.getWorkers());
      this.withOptions(instance.getOptions());
      this.withSize(instance.getSize());
      this.withWorkers(instance.getWorkers());
    }
    this.validationEnabled = validationEnabled; 
  }
  MemoryStressorFluent<?> fluent;
  Boolean validationEnabled;
  public MemoryStressor build() {
    MemoryStressor buildable = new MemoryStressor(fluent.getOptions(),fluent.getSize(),fluent.getWorkers());
    return buildable;
  }
  
}
